@@ -13,7 +13,7 @@ use DateTime;
 with 'PlugAuth::Role::Plugin';
 
 # ABSTRACT: Audit log for authentication/authorization
-our $VERSION = '0.29'; # VERSION
+our $VERSION = '0.30'; # VERSION
 
 
 with 'PlugAuth::Role::Plugin';
@@ -55,7 +55,7 @@ sub init
   my $authz = sub {
   };
   
-  $self->app->routes->bridge->to({ cb => $auth })->route('/audit/:year/:month/:day')->name('audit')->get(sub {
+  $self->app->routes->under->to({ cb => $auth })->route('/audit/:year/:month/:day')->name('audit')->get(sub {
     my($c) = @_;
     my $year  = $c->stash('year');
     my $month = $c->stash('month');
@@ -147,7 +147,7 @@ PlugAuth::Plugin::Audit - Audit log for authentication/authorization
 
 =head1 VERSION
 
-version 0.29
+version 0.30
 
 =head1 SYNOPSIS
 
